==> resttools-1.1.31-sources.jar: com/humandevice/android/resttools/rest/RestConfiguration.java <==
package com.humandevice.android.resttools.rest;

import android.text.TextUtils;

import com.humandevice.android.resttools.rest.exceptions.ErrorResponse;
import com.humandevice.android.resttools.service.IUserService;

import java.util.Arrays;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import okhttp3.Credentials;

/**
 * Klasa konfigurująca dane dostępowe do resta, takie jak host, port itp.
 *
 * @author Szymon Bartczak
 */
public class RestConfiguration {

    int mTimeout = 60 * 1000;

    String mApiScheme = "http";
    String mApiHost;
    int mApiPort = 80;
    String mAuthorization;
    String mAuthorizationUser;
    String mAuthorizationPassword;
    boolean mCastBooleanToInt;
    boolean mUnixTime = false;
    Set<Integer> mSuccessStatusCodes = new HashSet<>(Arrays.asList(new Integer[] {200}));
    Request.ConnectionRestriction mConnectionRestriction;
    Class<? extends IUserService> mUserServiceClass;
    Class<? extends ErrorResponse> mErrorResponseClass;
    Map<String, String> mHeaders = new LinkedHashMap<>();

    /**
     *  default: false
     */
    public RestConfiguration setUnixTime(boolean unixTime) {
        mUnixTime = unixTime;
        return this;
    }

    /**
     *  default: 1min
     */
    public RestConfiguration setTimeout(int timeout) {
        mTimeout = timeout;
        return this;
    }

    /**
     * default: http
     */
    public RestConfiguration setApiScheme(String apiScheme) {
        mApiScheme = apiScheme;
        return this;
    }

    public RestConfiguration setApiHost(String apiHost) {
        mApiHost = apiHost;
        return this;
    }

    /**
     * default: 80
     */
    public RestConfiguration setApiPort(int apiPort) {
        mApiPort = apiPort;
        return this;
    }

    public RestConfiguration setAuthorization(String user, String password) {
        if (TextUtils.isEmpty(user) && TextUtils.isEmpty(password)){
            mAuthorization = null;
            return this;
        }
        mAuthorization = Credentials.basic(user, password);
        mAuthorizationUser = user;
        mAuthorizationPassword = password;
        return this;
    }

    /**
     * cast all boolean parameters to int value (0/1)
     */
    public RestConfiguration setCastBooleanToInt() {
        mCastBooleanToInt = true;
        return this;
    }

    /**
     * Sprawdzenie czy request może zostać wykonany
     */
    public RestConfiguration setConnectionRestriction(Request.ConnectionRestriction connectionRestriction) {
        mConnectionRestriction = connectionRestriction;
        return this;
    }

	/**
     * Ustawienie klasy singletona serwisu użytkownika
     */
    public RestConfiguration setUserServiceClass(Class<? extends IUserService> userServiceClass) {
        mUserServiceClass = userServiceClass;
        return this;
    }

	/**
     * Ustawienie klasy odpowiedzi błędu
     */
    public RestConfiguration setErrorResponseClass(Class<? extends ErrorResponse> errorResponseClass) {
        mErrorResponseClass = errorResponseClass;
        return this;
    }

	/**
     * Dodanie headera dla wszystkich zapytań
     */
    public RestConfiguration addStaticHeader(String name, String value) {
        mHeaders.put(name, value);
        return this;
    }

    public int getTimeout() {
        return mTimeout;
    }

    public String getApiScheme() {
        return mApiScheme;
    }

    public String getApiHost() {
        return mApiHost;
    }

    public int getApiPort() {
        return mApiPort;
    }

    public String getAuthorization() {
        return mAuthorization;
    }

    public String getAuthorizationUser() {
        return mAuthorizationUser;
    }

    public String getAuthorizationPassword() {
        return mAuthorizationPassword;
    }

    public boolean isCastBooleanToInt() {
        return mCastBooleanToInt;
    }

    public boolean isUnixTime() {
        return mUnixTime;
    }

    public Request.ConnectionRestriction getConnectionRestriction() {
        return mConnectionRestriction;
    }

    public Class<? extends IUserService> getUserServiceClass() {
        return mUserServiceClass;
    }

    public Class<? extends ErrorResponse> getErrorResponseClass() {
        return mErrorResponseClass;
    }

    public void setSuccessStatusCodes(Integer... successStatusCodes) {
        mSuccessStatusCodes.clear();
        List<Integer> integers = Arrays.asList(successStatusCodes);
        mSuccessStatusCodes.addAll(integers);
    }

    public Set<Integer> getSuccessStatusCodes() {
        return mSuccessStatusCodes;
    }
}

==> resttools-1.1.35-sources.jar: com/humandevice/android/resttools/rest/RestConfiguration.java <==
package com.humandevice.android.resttools.rest;

import android.text.TextUtils;

import com.humandevice.android.resttools.rest.exceptions.ErrorResponse;
import com.humandevice.android.resttools.service.IUserService;

import java.util.Arrays;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import okhttp3.Credentials;

/**
 * Klasa konfigurująca dane dostępowe do resta, takie jak host, port itp.
 *
 * @author Szymon Bartczak
 */
public class RestConfiguration {

    int mTimeout = 60 * 1000;

    String mApiScheme = "http";
    String mApiHost;
    int mApiPort = 80;
    String mAuthorization;
    String mAuthorizationUser;
    String mAuthorizationPassword;
    boolean mCastBooleanToInt;
    boolean mUnixTime = false;
    Set<Integer> mSuccessStatusCodes = new HashSet<>(Arrays.asList(new Integer[] {200}));
    Request.ConnectionRestriction mConnectionRestriction;
    ErrorCallback mErrorCallback;
    Class<? extends IUserService> mUserServiceClass;
    Class<? extends ErrorResponse> mErrorResponseClass;
    Map<String, String> mHeaders = new LinkedHashMap<>();

    /**
     *  default: false
     */
    public RestConfiguration setUnixTime(boolean unixTime) {
        mUnixTime = unixTime;
        return this;
    }

    /**
     *  default: 1min
     */
    public RestConfiguration setTimeout(int timeout) {
        mTimeout = timeout;
        return this;
    }

    /**
     * default: http
     */
    public RestConfiguration setApiScheme(String apiScheme) {
        mApiScheme = apiScheme;
        return this;
    }

    public RestConfiguration setApiHost(String apiHost) {
        mApiHost = apiHost;
        return this;
    }

    /**
     * default: 80
     */
    public RestConfiguration setApiPort(int apiPort) {
        mApiPort = apiPort;
        return this;
    }

    public RestConfiguration setAuthorization(String user, String password) {
        if (TextUtils.isEmpty(user) && TextUtils.isEmpty(password)){
            mAuthorization = null;
            return this;
        }
        mAuthorization = Credentials.basic(user, password);
        mAuthorizationUser = user;
        mAuthorizationPassword = password;
        return this;
    }

    /**
     * cast all boolean parameters to int value (0/1)
     */
    public RestConfiguration setCastBooleanToInt() {
        mCastBooleanToInt = true;
        return this;
    }

    /**
     * Sprawdzenie czy request może zostać wykonany
     */
    public RestConfiguration setConnectionRestriction(Request.ConnectionRestriction connectionRestriction) {
        mConnectionRestriction = connectionRestriction;
        return this;
    }


    /**
     * Metoda wywoływana jeśli wystąpi jakiś błąd podczas zapytania api
     */
    public RestConfiguration setErrorCallback(ErrorCallback callback) {
        mErrorCallback = callback;
        return this;
    }

    /**
     * Ustawienie klasy singletona serwisu użytkownika
     */
    public RestConfiguration setUserServiceClass(Class<? extends IUserService> userServiceClass) {
        mUserServiceClass = userServiceClass;
        return this;
    }

	/**
     * Ustawienie klasy odpowiedzi błędu
     */
    public RestConfiguration setErrorResponseClass(Class<? extends ErrorResponse> errorResponseClass) {
        mErrorResponseClass = errorResponseClass;
        return this;
    }

	/**
     * Dodanie headera dla wszystkich zapytań
     */
    public RestConfiguration addStaticHeader(String name, String value) {
        mHeaders.put(name, value);
        return this;
    }

    public int getTimeout() {
        return mTimeout;
    }

    public String getApiScheme() {
        return mApiScheme;
    }

    public String getApiHost() {
        return mApiHost;
    }

    public int getApiPort() {
        return mApiPort;
    }

    public String getAuthorization() {
        return mAuthorization;
    }

    public String getAuthorizationUser() {
        return mAuthorizationUser;
    }

    public String getAuthorizationPassword() {
        return mAuthorizationPassword;
    }

    public boolean isCastBooleanToInt() {
        return mCastBooleanToInt;
    }

    public boolean isUnixTime() {
        return mUnixTime;
    }

    public Request.ConnectionRestriction getConnectionRestriction() {
        return mConnectionRestriction;
    }

    public Class<? extends IUserService> getUserServiceClass() {
        return mUserServiceClass;
    }

    public Class<? extends ErrorResponse> getErrorResponseClass() {
        return mErrorResponseClass;
    }

    public void setSuccessStatusCodes(Integer... successStatusCodes) {
        mSuccessStatusCodes.clear();
        List<Integer> integers = Arrays.asList(successStatusCodes);
        mSuccessStatusCodes.addAll(integers);
    }

    public Set<Integer> getSuccessStatusCodes() {
        return mSuccessStatusCodes;
    }
}
